@@ -1,9 +1,12 @@
 from models_manager.connect import Connect
+from models_manager.converters.constructor import construct_class
 from models_manager.manager.field.enums import FieldGenericEnum
 from models_manager.manager.field.field import Field
 from models_manager.manager.model import Model
 from models_manager.manager.query.node import Q
 from models_manager.providers.provider import Provider
+from models_manager.schema.provider import SchemaProvider
+from models_manager.schema.schema_typing import resolve_typing
 
 __all__ = [
     'Q',
@@ -11,5 +14,8 @@ __all__ = [
     'Model',
     'Connect',
     'Provider',
-    'FieldGenericEnum'
+    'FieldGenericEnum',
+    'SchemaProvider',
+    'resolve_typing',
+    'construct_class'
 ]
