@@ -38,3 +38,15 @@ class QuerySetOperationError(Exception):
 
 class ProviderException(Exception):
     pass
+
+
+class SchemaException(Exception):
+    pass
+
+
+class JsonException(Exception):
+    pass
+
+
+class NegativeValuesException(Exception):
+    pass
